@@ -3,6 +3,8 @@ for Unimatrix packages.
 """
 import asyncio
 import importlib
+import time
+from concurrent.futures import ThreadPoolExecutor
 
 import sqlalchemy
 import sqlalchemy.ext.declarative
@@ -13,8 +15,9 @@ from sqlalchemy.sql.schema import MetaData
 from sqlalchemy.orm import sessionmaker
 
 from .base import Relation
-from .conf import DATABASES
+from .conf import DatabaseConnection
 from .conf import load_config
+from .conf import DATABASES
 from .repository import RelationalDatabaseRepository
 
 
@@ -22,6 +25,45 @@ ENGINES = {}
 ASYNC_ENGINES = {}
 
 
+def awaitservices(max_retries=60, interval=1, databases=None):
+    """Block until all database connections are available.
+
+    Args:
+        max_retries (int): the maximum number of retries. Defaults to ``60``.
+        interval (int): the interval between retries, in seconds. Defaults
+            to ``1``.
+
+    Returns:
+        None
+
+    Raises:
+        :exc:`RuntimeError`
+    """
+    databases = databases or DATABASES
+    with ThreadPoolExecutor(max_workers=len(databases)) as executor:
+        ready = []
+        attempts = 0
+        while True:
+            if set(ready) == set(dict.keys(databases)):
+                break
+            if attempts >= max_retries:
+                raise RuntimeError(
+                    "Connections not ready after %s retries." % attempts)
+            futures = executor.map(
+                DatabaseConnection.wait,
+                [databases[name]
+                    for name in dict.keys(databases)
+                    if name not in ready
+                ]
+            )
+            for result in futures:
+                if result is not None:
+                    ready.append(result.name)
+
+            attempts += 1
+            time.sleep(interval)
+
+
 def declarative_base(cls=None, class_factory=None, settings=None, apps=None):
     """Like :func:`sqlalchemy.ext.declarative.declarative_base()`, but
     returns a tuple containing the metadata objects for all applications
