@@ -11,7 +11,7 @@ class RelationalDatabaseRepository:
         if getattr(self, 'session', None) is None:
             self._manages_session = True
             if isinstance(self.session_factory, str):
-                self.session = ioc.require(self.ioc_session_factory_key)()
+                self.session = ioc.require(self.session_factory)()
             elif callable(self.session_factory):
                 self.session = self.session_factory()
             else:
